<?php
class Altima_Catalog_Model_Observer
{
	private $__positionOrders = array('position' => 'asc' ,'news_from_date' => 'desc' ,'price' => 'asc');

    /**
     * Set the good direction for each sort
     *
     * @param Varien_Event_Observer $observer
     */
    public function setGoodDirection(Varien_Event_Observer $observer)
    {
		// We need to set the direction in this observer and not in the other
		// because the Mage_Review Observer load the product collection and after we can't set direction
        $block = $observer->getEvent()->getBlock();

        if ($block instanceof Mage_Catalog_Block_Product_List) {
			$toolbar =  $block->getToolbarBlock();
			if($toolbar){
				// We get Collection in order to launch the prepareSortableFieldsByCategory method
				// This method will retrieve the default sort parameter for the category (if there is one)
				$collection = $block->getLoadedProductCollection(); 
				// If current order is in request, we use it
				$customOrder = Mage::app()->getRequest()->getParam('order');
				if($customOrder){
					$finalOrder = $customOrder;
				} else {
					$finalOrder = $block->getSortBy();
				}
				// We set the current order
				$toolbar->setData('_current_grid_order', $finalOrder);
				foreach($this->__positionOrders AS $order => $direction){
					// If it's current order, we apply our custom direction
					if($toolbar->isOrderCurrent($order)){
						// If current direction is in request, we use it
						$customDirection = Mage::app()->getRequest()->getParam('dir');
						if($customDirection){
							$finalDirection = $customDirection;
						} else {
							$finalDirection = $direction;
						}
						// We set the current direction
						$toolbar->setData('_current_grid_direction', $finalDirection);
						$toolbar->setDefaultDirection($finalDirection);
					}
				}
			}
		}
		return $this;
    }
	
	public function changeSelectOrders(Varien_Event_Observer $observer)
	{
		// We need to change the select options order here because in this observer
		// changes made on the toolbar doesn't take effect
		$toolbar = Mage::app()->getLayout()->getBlock('product_list_toolbar');
		// We change the order of the select options
		$positionsOrders = $this->__positionOrders;
		$orders = $toolbar->getAvailableOrders();
		$sortedOrders = array();
		
		// If catalogsearch, remove position
		$actionName = Mage::app()->getFrontController()->getAction()->getFullActionName();
		if($actionName == "catalogsearch_result_index"){
			if(isset($positionsOrders['position'])){
				unset($positionsOrders['position']);
			}
		}
		
		// We put the order defined in the array
		foreach($positionsOrders AS $order => $direction){
			if(isset($orders[$order])){
				$sortedOrders[$order] = $orders[$order];
				unset($orders[$order]);
			}
		}
		// If there is other orders, we put its at the end of the array
		foreach($orders AS $key => $label){
			$sortedOrders[$key] = $orders[$key];
		}
		// We set our new sorted array to the toolbar
		$toolbar->setAvailableOrders($sortedOrders);
		return $this;
		
	}

}
